@@ -41,7 +41,7 @@ void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ust
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
 
 #ifdef BAKERY_MAEMO_ENABLED
-  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING));
+  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING);
 #else
   Gtk::MessageDialog dialog(App_Gtk::util_bold_message(text), true /* use markup */, Gtk::MESSAGE_WARNING);
   dialog.set_secondary_text(secondary_text);
@@ -60,7 +60,7 @@ Glib::ustring GtkDialogs::ui_file_select_open(App& app, const Glib::ustring& sta
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
 
 #ifdef BAKERY_MAEMO_ENABLED
-  Hildon::FileChooserDialog fileChooser_Open(Gtk::FILE_CHOOSER_ACTION_OPEN));
+  Hildon::FileChooserDialog fileChooser_Open(Gtk::FILE_CHOOSER_ACTION_OPEN);
 #else
   Gtk::FileChooserDialog fileChooser_Open(gettext("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
   fileChooser_Open.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
