@@ -24,6 +24,8 @@
 #include <gtkmm/combo.h>
 #include <gtkmm/optionmenu.h>
 
+#include "config.h"
+
 namespace Bakery
 {
 
@@ -73,12 +75,6 @@ void Client::add_implementation(const Glib::ustring& key, Gtk::Widget& widget, b
     add_association(key, static_cast<Gtk::ToggleButton&>(widget), instant);
   else if (dynamic_cast<Gtk::Range*>(&widget))
     add_association(key, static_cast<Gtk::Range&>(widget), instant);
-  else if (dynamic_cast<Gtk::OptionMenu*>(&widget))
-    add_association(key, static_cast<Gtk::OptionMenu&>(widget), instant);
-  else if (dynamic_cast<Gtk::Combo*>(&widget))
-    add_association(key, static_cast<Gtk::Combo&>(widget), instant);
-
-  // TODO: Support for connecting a Gtk::Curve widget to an array of floating point values
 }
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
