@@ -42,7 +42,21 @@ void ExampleWindow::on_button_clicked()
 
   for(long i = 0; i < 10000; i++)
   {
-  long a = i * 5;
+    //Test an inner BusyCursor:
+    {
+      Bakery::BusyCursor cursor(*this);
+    }
+
+    //Using std::cout should take some time:
+    std::cout << "processing" << std::endl;
+ 
+    for(long l = 0; l < 10; l++)
+    {
+      //Using std::cout should take some time:
+      std::cout << "inner processing" << i << ", " << l << std::endl;
+ 
+    }
+    
   }
 }
 
